@@ -147,12 +147,13 @@ class Candidate:
         full_output = {
             "api_validation": self.api_validation.name,
             "ml_validation": self.ml_validation.name,
-            "line_data_list": [line_data.to_json() for line_data in self.line_data_list],
             "patterns": [pattern.pattern for pattern in self.patterns],
             "ml_probability": self.ml_probability,
             "rule": self.rule_name,
             "severity": self.severity.value,
             "use_ml": self.use_ml,
+            # put the array to end to make json more readable
+            "line_data_list": [line_data.to_json() for line_data in self.line_data_list],
         }
         if self.config is not None:
             reported_output = {k: v for k, v in full_output.items() if k in self.config.candidate_output}
@@ -179,17 +180,10 @@ class Candidate:
         return reported_output
 
     @classmethod
-    def get_dummy_candidate(cls, config: Config, file_path: str):
+    def get_dummy_candidate(cls, config: Config, file_path: str, file_type: str, info: str):
         """Create dummy instance to use in searching file by extension"""
         return cls(  #
-            line_data_list=[  #
-                LineData(  #
-                    config,  #
-                    line="dummy line",  #
-                    line_num=-1,  #
-                    path=file_path,  #
-                    pattern=regex.compile(".*"))
-            ],
+            line_data_list=[LineData(config, "dummy line", -1, file_path, file_type, info, regex.compile(".*"))],
             patterns=[regex.compile(".*")],  #
             rule_name="Dummy candidate",  #
             severity=Severity.INFO,  #
