@@ -4,8 +4,11 @@ from credsweeper.credentials.line_data import LineData
 
 
 class CandidateKey:
-    """Class used to identify credential candidates. Candidates that detected same value on same string in a same file
-        would have identical CandidateKey"""
+    """Class used to identify credential candidates.
+
+    Candidates that detected same value on same string in a same file would have identical CandidateKey
+    """
+
     def __init__(self, line_data: LineData):
         self.path: str = line_data.path
         self.line_num: int = line_data.line_num
