@@ -3,7 +3,8 @@ from credsweeper.filters import Filter
 
 
 class ValueBlocklistCheck(Filter):
-    """Check that words from block list is lest that 70% of candidate value length"""
+    """Check that words from block list is lest that 70% of candidate value length."""
+
     NOT_ALLOWED = [
         "true",
         "false",
@@ -13,13 +14,14 @@ class ValueBlocklistCheck(Filter):
     ]
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
