@@ -4,18 +4,20 @@ from credsweeper.filters import Filter
 
 
 class ValueDictionaryKeywordCheck(Filter):
-    """Check that no word from dictionary present in the candidate value"""
+    """Check that no word from dictionary present in the candidate value."""
+
     def __init__(self) -> None:
         self.keyword_checklist = KeywordChecklist()
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
