@@ -3,7 +3,10 @@ from credsweeper.filters import Filter
 
 
 class ValueLengthCheck(Filter):
-    """Check if potential candidate value is not too short (longer than 4)."""
+    """Check if potential candidate value is not too short (longer or equal to `min_len`)."""
+
+    def __init__(self, min_len) -> None:
+        self.min_len = min_len
 
     def run(self, line_data: LineData) -> bool:
         """Run filter checks on received credential candidate data 'line_data'.
@@ -17,6 +20,6 @@ class ValueLengthCheck(Filter):
         """
         if line_data.value is None:
             return True
-        if len(line_data.value) < 4:
+        if len(line_data.value) < self.min_len:
             return True
         return False
