@@ -5,17 +5,22 @@ from credsweeper.filters import Filter
 
 
 class ValueMethodCheck(Filter):
-    """Check if potential candidate value is a function by looking for '(', ')' or 'function' sub-strings in it"""
+    """Check if potential candidate value is a function.
+
+    Check if potential candidate value is a function by looking for '(', ')' or 'function' sub-strings in it
+    """
+
     PATTERN = regex.compile(".*\\(.*\\).*")
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
